==> opencart_v1.2.6.zip: opencart_v1.2.6/upload/admin/language/english/common/menu.php <==
<?php
// Heading
$_['heading_title']         = 'Menu';

// Text
$_['text_admin']            = 'Admin';
$_['text_backup']           = 'Backup / Restore';
$_['text_catalog']          = 'Catalog';
$_['text_category']         = 'Category';
$_['text_configuration']    = 'Configuration';
$_['text_country']          = 'Country'; 
$_['text_coupon']           = 'Coupon';
$_['text_currency']         = 'Currency';
$_['text_customer']         = 'Customer';
$_['text_customers']        = 'Customers';
$_['text_download']         = 'Download';
$_['text_extension']        = 'Extensions';
$_['text_feed']             = 'Feeds';
$_['text_geo_zone']         = 'Geo Zone';
$_['text_home']             = 'Home';
$_['text_information']      = 'Information';
$_['text_language']         = 'Language';
$_['text_localisation']     = 'Localisation';
$_['text_logout']           = 'Logout';
$_['text_mail']             = 'Mail';
$_['text_manufacturer']     = 'Manufacturer';
$_['text_module']           = 'Modules';
$_['text_order']            = 'Order';
$_['text_order_status']     = 'Order Status';
$_['text_payment']          = 'Payment';
$_['text_product']          = 'Product';
$_['text_reports']          = 'Reports';
$_['text_report_sale']      = 'Sales';
$_['text_report_viewed']    = 'Products Viewed';
$_['text_report_purchased'] = 'Products Purchased';
$_['text_review']           = 'Review';
$_['text_shipping']         = 'Shipping';
$_['text_shop']             = 'Online Shop';
$_['text_setting']          = 'Setting';
$_['text_stock_status']     = 'Stock Status';
$_['text_tax_class']        = 'Tax Class';
$_['text_total']            = 'Order Total';
$_['text_user']             = 'User';
$_['text_users']            = 'Users';
$_['text_user_group']       = 'User Group';
$_['text_weight_class']     = 'Weight Class';
$_['text_zone']             = 'Zone';
?>

==> opencart_v1.3.0.zip: opencart_v1.3.0/upload/admin/language/english/common/menu.php <==
<?php
// Heading
$_['heading_title']         = 'Menu';

// Text
$_['text_admin']            = 'Admin';
$_['text_backup']           = 'Backup / Restore';
$_['text_catalog']          = 'Catalog';
$_['text_category']         = 'Category';
$_['text_configuration']    = 'Configuration';
$_['text_country']          = 'Country'; 
$_['text_coupon']           = 'Coupon';
$_['text_currency']         = 'Currency';
$_['text_customer']         = 'Customer';
$_['text_customers']        = 'Customers';
$_['text_download']         = 'Download';
$_['text_extension']        = 'Extensions';
$_['text_feed']             = 'Product Feeds';
$_['text_geo_zone']         = 'Geo Zone';
$_['text_home']             = 'Home';
$_['text_help']             = 'Help';
$_['text_information']      = 'Information';
$_['text_language']         = 'Language';
$_['text_localisation']     = 'Localisation';
$_['text_logout']           = 'Logout';
$_['text_contact']          = 'Mail';
$_['text_manufacturer']     = 'Manufacturer';
$_['text_module']           = 'Modules';
$_['text_order']            = 'Order';
$_['text_order_status']     = 'Order Status';
$_['text_payment']          = 'Payment';
$_['text_product']          = 'Product';
$_['text_reports']          = 'Reports';
$_['text_report_sale']      = 'Sales';
$_['text_report_viewed']    = 'Products Viewed';
$_['text_report_purchased'] = 'Products Purchased';
$_['text_review']           = 'Review';
$_['text_shipping']         = 'Shipping';
$_['text_shop']             = 'Online Shop';
$_['text_setting']          = 'Setting';
$_['text_stock_status']     = 'Stock Status';
$_['text_support']          = 'Support Forum';
$_['text_tax_class']        = 'Tax Class';
$_['text_total']            = 'Order Total';
$_['text_user']             = 'User';
$_['text_documentation']    = 'Documentation';
$_['text_users']            = 'Users';
$_['text_user_group']       = 'User Group';
$_['text_weight_class']     = 'Weight Class';
$_['text_opencart']         = 'Homepage';
$_['text_zone']             = 'Zone';
?>
